@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/browse.php,v 1.76.2.23 2006/03/10 05:30:06 selsky Exp $
+ * $Horde: turba/browse.php,v 1.76.2.25.2.1 2008/02/15 16:44:11 chuck Exp $
  *
  * Turba: Copyright 2000-2005 Charles J. Hagenbuch <chuck@horde.org>
  *
@@ -30,7 +30,7 @@ $title = _("Address Book Listing");
 if (!$browse_source_count && Util::getFormData('key') != '**search') {
     $notification->push(_("There are no browseable address books."), 'horde.warning');
 } else {
-    $driver = &Turba_Driver::singleton($source);
+    $driver = &Turba_Driver::singleton($default_source);
     if (is_a($driver, 'PEAR_Error')) {
         $notification->push(sprintf(_("Failed to access the address book: %s"), $driver->getMessage()), 'horde.error');
         unset($driver);
@@ -195,7 +195,11 @@ if (isset($driver)) {
                 $notification->push($target, 'horde.error');
                 break;
             }
+        } else {
+            $targetSource = Util::getFormData('targetAddressbook');
+            $targetDriver = &Turba_Driver::singleton($targetSource);
         }
+
         if (!empty($target) && $target->isGroup()) {
             // Adding contact to an existing list.
             if (is_array($keys)) {
@@ -221,10 +225,10 @@ if (isset($driver)) {
             }
         } else {
             // Check permissions.
-            $max_contacts = Turba::hasPermission($source . ':max_contacts', 'source');
+            $max_contacts = Turba::hasPermission($default_source . ':max_contacts', 'source');
             if ($max_contacts !== true &&
                 $max_contacts <= $driver->countContacts()) {
-                $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d contacts in \"%s\"."), $max_contacts, $cfgSources[$source]['title']), ENT_COMPAT, NLS::getCharset());
+                $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d contacts in \"%s\"."), $max_contacts, $cfgSources[$default_source]['title']), ENT_COMPAT, NLS::getCharset());
                 if (!empty($conf['hooks']['permsdenied'])) {
                     $message = Horde::callHook('_perms_hook_denied', array('turba:max_contacts'), 'horde', $message);
                 }
@@ -234,16 +238,16 @@ if (isset($driver)) {
             }
             // Adding contact to a new list.
             $newList = array();
-            if ($driver->usingShares) {
-                $newList['__owner'] = $driver->share->get('uid');
+            if ($targetDriver->usingShares) {
+                $newList['__owner'] = $targetDriver->share->get('uid');
             } else {
                 $newList['__owner'] = Auth::getAuth();
             }
             $newList['__type'] = 'Group';
             $newList['name'] = $targetKey;
 
-            $targetKey = $driver->add($newList);
-            $target = &$driver->getObject($targetKey);
+            $targetKey = $targetDriver->add($newList);
+            $target = &$targetDriver->getObject($targetKey);
             if (!is_a($target, 'PEAR_Error') && $target->isGroup()) {
                 $notification->push(sprintf(_("Successfully created the contact list \"%s\"."), $newList['name']), 'horde.success');
                 if (is_array($keys)) {
@@ -276,7 +280,7 @@ if (isset($driver)) {
 
     // We might get here from the search page but are not allowed to browse
     // the current address book.
-    if ($actionID && empty($cfgSources[$source]['browse'])) {
+    if ($actionID && empty($cfgSources[$default_source]['browse'])) {
         header('Location: ' . Horde::applicationUrl($prefs->getValue('initial_page'), true));
         exit;
     }
@@ -288,7 +292,7 @@ if (isset($driver)) {
 
     // Read the columns to display from the preferences.
     $sources = Turba::getColumns();
-    $columns = isset($sources[$source]) ? $sources[$source] : array();
+    $columns = isset($sources[$default_source]) ? $sources[$default_source] : array();
 
     // Determine the name of the column to sort by.
     $sortcolumn = ($prefs->getValue('sortby') == 0 ||
@@ -311,6 +315,10 @@ if (isset($driver)) {
             if (!is_object($results = $list->listMembers($sortcolumn, $prefs->getValue('sortdir')))) {
                 $notification->push(_("Failed to browse list"), 'horde.error');
             } else {
+                if ($results->count() != $list->count()) {
+                    $notification->push(sprintf(_("There are %d contact(s) in this list that are not viewable to you"),
+                                                ($list->count() - $results->count())), 'horde.message');
+                }
                 $view = &new Turba_ListView($results);
                 $view->setType('list');
             }
@@ -319,9 +327,9 @@ if (isset($driver)) {
         }
     } else {
         // We are displaying an address book.
-        $title = $cfgSources[$source]['title'];
+        $title = $cfgSources[$default_source]['title'];
         $templates[] = '/browse/header.inc';
-        if (empty($cfgSources[$source]['browse'])) {
+        if (empty($cfgSources[$default_source]['browse'])) {
             $notification->push(_("Your default address book is not browseable."), 'horde.warning');
         } else {
             if (Util::getFormData('show', 'all') == 'contacts') {
