@@ -5,7 +5,7 @@ require_once 'Horde/Cache.php';
 /**
  * Turba directory driver implementation for an IMSP server.
  *
- * $Horde: turba/lib/Driver/imsp.php,v 1.21.4.12 2006/05/31 17:06:38 selsky Exp $
+ * $Horde: turba/lib/Driver/imsp.php,v 1.21.4.15 2007/08/05 19:30:08 mrubinsk Exp $
  *
  * @author  Michael Rubinsky <mrubinsk@horde.org>
  * @package Turba
@@ -129,14 +129,18 @@ class Turba_Driver_imsp extends Turba_Driver {
         $namesCount = count($names);
         for ($i = 0; $i < $namesCount; $i++) {
             $temp = $this->_read('name', array($names[$i]), $fields);
-            $result = $temp[0];
-            if (is_a($result, 'PEAR_Error')) {
-                $GLOBALS['notification']->push($results, 'horde.error');
-            } elseif (($this->_noGroups) && (isset($result[$this->_groupField])) &&
-                      ($result[$this->_groupField]) == $this->_groupValue) {
-                unset($result);
+            if (is_a($temp, 'PEAR_Error')) {
+                $GLOBALS['notification']->push($temp, 'horde.error');
             } else {
-                $results[] = $result;
+                $result = $temp[0];
+                if (is_a($result, 'PEAR_Error')) {
+                    $GLOBALS['notification']->push($results, 'horde.error');
+                } elseif (($this->_noGroups) && (isset($result[$this->_groupField])) &&
+                          ($result[$this->_groupField]) == $this->_groupValue) {
+                    unset($result);
+                } else {
+                    $results[] = $result;
+                }
             }
         }
 
@@ -198,7 +202,7 @@ class Turba_Driver_imsp extends Turba_Driver {
                         }
                     }
                     if (isset($temp['__members'])) {
-                        $tmembers = unserialize($temp['__members']);
+                        $tmembers = @unserialize($temp['__members']);
                     }
                     $temp['__members'] = serialize($this->_removeDuplicated(
                                                    array($members, $tmembers)));
@@ -247,12 +251,14 @@ class Turba_Driver_imsp extends Turba_Driver {
 
             if (count($members)) {
                 $result = $this->_read('name', $members, array('email'));
-                $count = count($result);
-                for ($i = 0; $i < $count; $i++) {
-                    if (isset($result[$i]['email'])) {
-                        $contact = sprintf("%s<%s>\n", $members[$i],
-                                           $result[$i]['email']);
-                        $attributes['email'] .= $contact;
+                if (!is_a($result, 'PEAR_Error')) {
+                    $count = count($result);
+                    for ($i = 0; $i < $count; $i++) {
+                        if (isset($result[$i]['email'])) {
+                            $contact = sprintf("%s<%s>\n", $members[$i],
+                                               $result[$i]['email']);
+                            $attributes['email'] .= $contact;
+                        }
                     }
                 }
             }
@@ -515,7 +521,9 @@ class Turba_Driver_imsp extends Turba_Driver {
     {
         $unames = array();
         for ($i = 0; $i < count($names); $i++) {
-            $unames = array_merge($unames, $names[$i]);
+            if (is_array($names[$i])) {
+                $unames = array_merge($unames, $names[$i]);
+            }
         }
         return array_unique($unames);
     }
